import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 论文信息服务对象基类
 *
 * @export
 * @class HRPaperServiceBase
 * @extends {EntityServie}
 */
export default class HRPaperServiceBase extends EntityService {

    /**
     * Creates an instance of  HRPaperServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  HRPaperServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof HRPaperServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='hrpaper';
        this.APPDEKEY = 'hrpaperid';
        this.APPDENAME = 'hrpapers';
        this.APPDETEXT = 'hrpapername';
        this.APPNAME = 'pim';
        this.SYSTEMNAME = 'ibizhumanresources';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrpaper){
            let res:any = Http.getInstance().get(`/hremployees/${context.hremployee}/hrpapers/${context.hrpaper}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/hrpapers/${context.hrpaper}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/hremployees/${context.hremployee}/hrpapers`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/hrpapers`,data,isloading);
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrpaper){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/hremployees/${context.hremployee}/hrpapers/${context.hrpaper}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/hrpapers/${context.hrpaper}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrpaper){
            let res:any = Http.getInstance().delete(`/hremployees/${context.hremployee}/hrpapers/${context.hrpaper}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/hrpapers/${context.hrpaper}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrpaper){
            let res:any = await Http.getInstance().get(`/hremployees/${context.hremployee}/hrpapers/${context.hrpaper}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/hrpapers/${context.hrpaper}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && true){
            let res:any = await Http.getInstance().get(`/hremployees/${context.hremployee}/hrpapers/getdraft`,isloading);
            res.data.hrpaper = data.hrpaper;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/hrpapers/getdraft`,isloading);
        res.data.hrpaper = data.hrpaper;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrpaper){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hremployees/${context.hremployee}/hrpapers/${context.hrpaper}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/hrpapers/${context.hrpaper}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrpaper){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hremployees/${context.hremployee}/hrpapers/${context.hrpaper}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/hrpapers/${context.hrpaper}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPaperServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/hremployees/${context.hremployee}/hrpapers/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hrpapers/fetchdefault`,tempData,isloading);
        return res;
    }
}